summaryrefslogtreecommitdiffstats
path: root/drivers/net/wireless/wl12xx/tx.h
diff options
context:
space:
mode:
authorArik Nemtsov <arik@wizery.com>2010-10-16 18:53:48 +0200
committerLuciano Coelho <coelho@ti.com>2011-01-24 22:11:48 +0200
commitbeb6c880720073c233633c45792a4bb5d5fedbd5 (patch)
tree303f38897f1b94c59b1fa7c5098a8e374ca1003f /drivers/net/wireless/wl12xx/tx.h
parentae113b57826b40f1962a6e2417efd757b638e6a9 (diff)
downloadblackbird-op-linux-beb6c880720073c233633c45792a4bb5d5fedbd5.tar.gz
blackbird-op-linux-beb6c880720073c233633c45792a4bb5d5fedbd5.zip
wl12xx: Add AP related definitions to HOST-FW interface
Change structures in a non-destructive manner. This means no changes in size or location of existing members used by STA. Signed-off-by: Arik Nemtsov <arik@wizery.com> Reviewed-by: Luciano Coelho <coelho@ti.com> Signed-off-by: Luciano Coelho <coelho@ti.com>
Diffstat (limited to 'drivers/net/wireless/wl12xx/tx.h')
-rw-r--r--drivers/net/wireless/wl12xx/tx.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/drivers/net/wireless/wl12xx/tx.h b/drivers/net/wireless/wl12xx/tx.h
index 5ccd22eaf074..05722a560d91 100644
--- a/drivers/net/wireless/wl12xx/tx.h
+++ b/drivers/net/wireless/wl12xx/tx.h
@@ -29,6 +29,7 @@
#define TX_HW_BLOCK_SIZE 252
#define TX_HW_MGMT_PKT_LIFETIME_TU 2000
+#define TX_HW_AP_MODE_PKT_LIFETIME_TU 8000
/* The chipset reference driver states, that the "aid" value 1
* is for infra-BSS, but is still always used */
#define TX_HW_DEFAULT_AID 1
@@ -77,8 +78,12 @@ struct wl1271_tx_hw_descr {
u8 id;
/* The packet TID value (as User-Priority) */
u8 tid;
- /* Identifier of the remote STA in IBSS, 1 in infra-BSS */
- u8 aid;
+ union {
+ /* STA - Identifier of the remote STA in IBSS, 1 in infra-BSS */
+ u8 aid;
+ /* AP - host link ID (HLID) */
+ u8 hlid;
+ } __packed;
u8 reserved;
} __packed;
OpenPOWER on IntegriCloud